@@ -6,7 +6,7 @@
 #include "queueing.h"
 
 struct multicore_worker __percpu *
-packet_alloc_percpu_multicore_worker(work_func_t function, void *ptr)
+wg_packet_alloc_percpu_multicore_worker(work_func_t function, void *ptr)
 {
 	int cpu;
 	struct multicore_worker __percpu *worker =
@@ -22,8 +22,8 @@ packet_alloc_percpu_multicore_worker(work_func_t function, void *ptr)
 	return worker;
 }
 
-int packet_queue_init(struct crypt_queue *queue, work_func_t function,
-		      bool multicore, unsigned int len)
+int wg_packet_queue_init(struct crypt_queue *queue, work_func_t function,
+			 bool multicore, unsigned int len)
 {
 	int ret;
 
@@ -33,7 +33,7 @@ int packet_queue_init(struct crypt_queue *queue, work_func_t function,
 		return ret;
 	if (function) {
 		if (multicore) {
-			queue->worker = packet_alloc_percpu_multicore_worker(
+			queue->worker = wg_packet_alloc_percpu_multicore_worker(
 				function, queue);
 			if (!queue->worker)
 				return -ENOMEM;
@@ -43,7 +43,7 @@ int packet_queue_init(struct crypt_queue *queue, work_func_t function,
 	return 0;
 }
 
-void packet_queue_free(struct crypt_queue *queue, bool multicore)
+void wg_packet_queue_free(struct crypt_queue *queue, bool multicore)
 {
 	if (multicore)
 		free_percpu(queue->worker);
